@@ -4,6 +4,10 @@ use std::path::PathBuf;
 
 fn main() {
     println!("cargo:rustc-link-lib=X11");
+    println!("cargo:rustc-link-lib=Xcomposite");
+    println!("cargo:rustc-link-lib=Xrender");
+    println!("cargo:rustc-link-lib=Xfixes");
+    println!("cargo:rustc-link-lib=Xext");
     println!("cargo:rustc-link-lib=GL");
     println!("cargo:rustc-link-lib=GLU");
 
